@@ -1,8 +1,5 @@
 package Net::HTTP::Spore::Middleware::Auth::Basic;
-{
-  $Net::HTTP::Spore::Middleware::Auth::Basic::VERSION = '0.06';
-}
-
+$Net::HTTP::Spore::Middleware::Auth::Basic::VERSION = '0.07';
 # ABSTRACT: middleware for Basic authentication
 
 use Moose;
@@ -34,13 +31,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::HTTP::Spore::Middleware::Auth::Basic - middleware for Basic authentication
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -57,17 +56,21 @@ Net::HTTP::Spore::Middleware::Auth::Basic is a middleware to handle Basic authen
 
 =item *
 
-franck cuny <franck@lumberjaph.net>
+Franck Cuny <franck.cuny@gmail.com>
 
 =item *
 
 Ash Berlin <ash@cpan.org>
 
+=item *
+
+Ahmad Fatoum <athreef@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by linkfluence.
+This software is copyright (c) 2012 by Linkfluence.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
