@@ -1,8 +1,5 @@
 package Net::HTTP::Spore::Middleware::Auth::OAuth;
-{
-  $Net::HTTP::Spore::Middleware::Auth::OAuth::VERSION = '0.06';
-}
-
+$Net::HTTP::Spore::Middleware::Auth::OAuth::VERSION = '0.07';
 # ABSTRACT: middleware for OAuth authentication
 
 use Moose;
@@ -223,13 +220,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::HTTP::Spore::Middleware::Auth::OAuth - middleware for OAuth authentication
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -260,17 +259,21 @@ Net::HTTP::Spore::Middleware::Auth::OAuth is a middleware to handle OAuth mechan
 
 =item *
 
-franck cuny <franck@lumberjaph.net>
+Franck Cuny <franck.cuny@gmail.com>
 
 =item *
 
 Ash Berlin <ash@cpan.org>
 
+=item *
+
+Ahmad Fatoum <athreef@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by linkfluence.
+This software is copyright (c) 2012 by Linkfluence.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
