@@ -1,8 +1,5 @@
 package Net::HTTP::Spore::Middleware::DoNotTrack;
-{
-  $Net::HTTP::Spore::Middleware::DoNotTrack::VERSION = '0.06';
-}
-
+$Net::HTTP::Spore::Middleware::DoNotTrack::VERSION = '0.07';
 # ABSTRACT: add a new header to not track
 
 use Moose;
@@ -19,13 +16,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::HTTP::Spore::Middleware::DoNotTrack - add a new header to not track
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -42,17 +41,21 @@ Add a header B<x-do-not-track> to your requests. For more details see L<http://d
 
 =item *
 
-franck cuny <franck@lumberjaph.net>
+Franck Cuny <franck.cuny@gmail.com>
 
 =item *
 
 Ash Berlin <ash@cpan.org>
 
+=item *
+
+Ahmad Fatoum <athreef@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by linkfluence.
+This software is copyright (c) 2012 by Linkfluence.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
