@@ -1,15 +1,12 @@
 package Net::HTTP::Spore::Middleware::Format::Auto;
-{
-  $Net::HTTP::Spore::Middleware::Format::Auto::VERSION = '0.06';
-}
-
+$Net::HTTP::Spore::Middleware::Format::Auto::VERSION = '0.07';
 use Moose;
 use MooseX::Types::Moose qw/HashRef Object/;
 extends 'Net::HTTP::Spore::Middleware::Format';
 
 use Try::Tiny;
 
-has seriliazer => (
+has serializer => (
     is      => 'rw',
     isa     => HashRef [Object],
     lazy    => 1,
@@ -53,13 +50,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::HTTP::Spore::Middleware::Format::Auto
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 DESCRIPTION
 
@@ -71,17 +70,21 @@ B<NOT WORKING>
 
 =item *
 
-franck cuny <franck@lumberjaph.net>
+Franck Cuny <franck.cuny@gmail.com>
 
 =item *
 
 Ash Berlin <ash@cpan.org>
 
+=item *
+
+Ahmad Fatoum <athreef@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by linkfluence.
+This software is copyright (c) 2012 by Linkfluence.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
