@@ -1,8 +1,5 @@
 package Net::HTTP::Spore::Middleware::Format::XML;
-{
-  $Net::HTTP::Spore::Middleware::Format::XML::VERSION = '0.06';
-}
-
+$Net::HTTP::Spore::Middleware::Format::XML::VERSION = '0.07';
 # ABSTRACT: middleware for XML format
 
 use Moose;
@@ -35,13 +32,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::HTTP::Spore::Middleware::Format::XML - middleware for XML format
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -62,17 +61,21 @@ This middleware will also deserialize content in the response. The deserialized
 
 =item *
 
-franck cuny <franck@lumberjaph.net>
+Franck Cuny <franck.cuny@gmail.com>
 
 =item *
 
 Ash Berlin <ash@cpan.org>
 
+=item *
+
+Ahmad Fatoum <athreef@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by linkfluence.
+This software is copyright (c) 2012 by Linkfluence.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
