@@ -1,8 +1,5 @@
 package Net::HTTP::Spore::Middleware::Runtime;
-{
-  $Net::HTTP::Spore::Middleware::Runtime::VERSION = '0.06';
-}
-
+$Net::HTTP::Spore::Middleware::Runtime::VERSION = '0.07';
 # ABSTRACT: add a new header with runtime
 
 use Moose;
@@ -30,13 +27,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::HTTP::Spore::Middleware::Runtime - add a new header with runtime
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -56,17 +55,21 @@ Net::HTTP::Spore::Middleware::Runtime is a middleware that add a new header to t
 
 =item *
 
-franck cuny <franck@lumberjaph.net>
+Franck Cuny <franck.cuny@gmail.com>
 
 =item *
 
 Ash Berlin <ash@cpan.org>
 
+=item *
+
+Ahmad Fatoum <athreef@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by linkfluence.
+This software is copyright (c) 2012 by Linkfluence.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
