@@ -1,8 +1,5 @@
 package Net::HTTP::Spore::Middleware::UserAgent;
-{
-  $Net::HTTP::Spore::Middleware::UserAgent::VERSION = '0.06';
-}
-
+$Net::HTTP::Spore::Middleware::UserAgent::VERSION = '0.07';
 # ABSTRACT: middleware to change the user-agent value
 
 use Moose;
@@ -22,13 +19,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::HTTP::Spore::Middleware::UserAgent - middleware to change the user-agent value
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -45,17 +44,21 @@ Net::HTTP::Spore::Middleware::UserAgent change the default value of the useragen
 
 =item *
 
-franck cuny <franck@lumberjaph.net>
+Franck Cuny <franck.cuny@gmail.com>
 
 =item *
 
 Ash Berlin <ash@cpan.org>
 
+=item *
+
+Ahmad Fatoum <athreef@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by linkfluence.
+This software is copyright (c) 2012 by Linkfluence.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
