@@ -1,8 +1,5 @@
 package Net::HTTP::Spore::Role::Description;
-{
-  $Net::HTTP::Spore::Role::Description::VERSION = '0.06';
-}
-
+$Net::HTTP::Spore::Role::Description::VERSION = '0.07';
 # ABSTRACT: attributes for API description
 
 use Moose::Role;
@@ -43,13 +40,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::HTTP::Spore::Role::Description - attributes for API description
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 AUTHORS
 
@@ -57,17 +56,21 @@ version 0.06
 
 =item *
 
-franck cuny <franck@lumberjaph.net>
+Franck Cuny <franck.cuny@gmail.com>
 
 =item *
 
 Ash Berlin <ash@cpan.org>
 
+=item *
+
+Ahmad Fatoum <athreef@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by linkfluence.
+This software is copyright (c) 2012 by Linkfluence.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
