@@ -1,9 +1,7 @@
 package Net::HTTP::Spore::Role::Middleware;
-{
-  $Net::HTTP::Spore::Role::Middleware::VERSION = '0.06';
-}
-
+$Net::HTTP::Spore::Role::Middleware::VERSION = '0.07';
 use Moose::Role;
+use Class::Load;
 use Scalar::Util qw/blessed/;
 
 has middlewares => (
@@ -19,7 +17,7 @@ has middlewares => (
 sub _load_middleware {
     my ( $self, $mw, $cond, @args ) = @_;
 
-    Class::MOP::load_class($mw) unless blessed($mw);
+    Class::Load::load_class($mw) unless blessed($mw);
 
     my $code = $mw->wrap( $cond, @args );
     $self->_trace_msg('== enabling middleware %s', $mw);
@@ -54,7 +52,7 @@ sub enable_if {
     confess "condition must be a code ref" if (!$cond || ref $cond ne 'CODE');
 
     if(ref($mw) eq 'CODE'){ # anonymous middleware
-        Class::MOP::load_class('Net::HTTP::Spore::Middleware');
+        Class::Load::load_class('Net::HTTP::Spore::Middleware');
         my $anon = Class::MOP::Class->create_anon_class(
             superclasses => ['Net::HTTP::Spore::Middleware'],
             methods => {
@@ -80,13 +78,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::HTTP::Spore::Role::Middleware
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 AUTHORS
 
@@ -94,17 +94,21 @@ version 0.06
 
 =item *
 
-franck cuny <franck@lumberjaph.net>
+Franck Cuny <franck.cuny@gmail.com>
 
 =item *
 
 Ash Berlin <ash@cpan.org>
 
+=item *
+
+Ahmad Fatoum <athreef@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by linkfluence.
+This software is copyright (c) 2012 by Linkfluence.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
